/*********************************************
 * [Code to manipulate navigation show/hide.] *
**********************************************/

// Navigation Bar
const navigation = document.getElementById('main-navigation');

// Burger button
const burger = document.querySelector('button.hamburger');

// Scroll position for show/hide desktop nav
let scrollStatus = window.scrollY;

/**
 * [Reset navbar if window resized.]
**/

window.addEventListener('resize', () => {
    navigation.removeAttribute('style');
    navigation.classList.remove('show');
    burger.setAttribute('aria-expanded', 'false');
    document.body.removeAttribute('style');
});


/**
 * [Makes navbar hidden when you scroll down and visible when you scroll up on desktop.]
**/
function desktopNavControls() {
    let scrollAmount = window.scrollY;
    if (scrollAmount < scrollStatus) {
        // Scrolled up
        // Visibility must be toggled so screenreaders don't read the hidden menu
        navigation.style.visibility = 'visible';
        navigation.classList.add('show');
    } else if (scrollAmount > navigation.offsetHeight) {
        // Scrolled down and past original bottom of navbar
        navigation.classList.remove('show');
        // Prevent stutter by applying sticky after transition
        setTimeout(() => {
            navigation.style.position = 'sticky';
            navigation.style.visibility = 'hidden';
        }, 300);
    } else {
        // Reset position to static when user is at top of page
        navigation.style.visibility = 'visible';
        navigation.style.position = 'static';
    }
    scrollStatus = scrollAmount;
}

/**
 * [Show navbar using burger button on tablet.]
**/
burger.addEventListener('click', () => {
    navigation.classList.toggle('show');
    if (navigation.classList.contains('show')) {
        // Stops user from scrolling while nav is open
        document.body.style.overflow = 'hidden';
        burger.setAttribute('aria-expanded', 'true');
    } else {
        burger.setAttribute('aria-expanded', 'false');
        document.body.style.overflow = 'initial';
    }
});

document.addEventListener('scroll', () => {
    if (window.innerWidth > 601) {
        desktopNavControls();
    }
})